@@ -9,7 +9,7 @@
  * emit is a #define in qt and a method name in sigc++, so you have to include
  * it before qt-anything
  */
-#include <sigc++/sigc++.h>
+//#include <sigc++/sigc++.h>
 
 /*
  * QT makes use of a GC symbol, which is also defined by libgc, that gets
